==> mapguide-1.0.1.tar.gz: mapguide-1.0.1/Common/Stylization/PolygonAdapter.h <==
//
//  Copyright (C) 2004-2006  Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#include "GeometryAdapter.h"

class LineBuffer;
class LineBufferPool;

class PolygonAdapter : public GeometryAdapter
{
public:

    PolygonAdapter(LineBufferPool*);
    virtual ~PolygonAdapter();

    virtual void Stylize(Renderer*                      renderer,
                         RS_FeatureReader*              features,
                         RS_FilterExecutor*             exec,
                         LineBuffer*                    lb,
                         MdfModel::FeatureTypeStyle*    style,
                         const MdfModel::MdfString*     tooltip = NULL,
                         const MdfModel::MdfString*     url = NULL
                         );

private:

    void ObtainStyle(   MdfModel::AreaSymbolization2D*    asym,
                        RS_FillStyle&                   fillStyle);

    std::map<void*, RS_FillStyle*> m_hAreaSymCache;
};

==> mapguide-1.2.0.tar.gz: mapguide-1.2.0/Common/Stylization/PolygonAdapter.h <==
//
//  Copyright (C) 2004-2007 by Autodesk, Inc.
//
//  This library is free software; you can redistribute it and/or
//  modify it under the terms of version 2.1 of the GNU Lesser
//  General Public License as published by the Free Software Foundation.
//
//  This library is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
//  Lesser General Public License for more details.
//
//  You should have received a copy of the GNU Lesser General Public
//  License along with this library; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//

#ifndef POLYGONADAPTER_H
#define POLYGONADAPTER_H

#include "GeometryAdapter.h"

class LineBuffer;
class LineBufferPool;

class PolygonAdapter : public GeometryAdapter
{
public:
    PolygonAdapter(LineBufferPool*);
    virtual ~PolygonAdapter();

    virtual void Stylize(Renderer*                      renderer,
                         RS_FeatureReader*              features,
                         RS_FilterExecutor*             exec,
                         LineBuffer*                    lb,
                         MdfModel::FeatureTypeStyle*    style,
                         const MdfModel::MdfString*     tooltip = NULL,
                         const MdfModel::MdfString*     url = NULL,
                         RS_ElevationSettings*          elevSettings = NULL
                         );

private:
    void ObtainStyle(MdfModel::AreaSymbolization2D* asym, RS_FillStyle& fillStyle);

    std::map<void*, RS_FillStyle*> m_hAreaSymCache;
};

#endif
